# Google Java Client Services required for GCDS

Google Java Client Services depends on the Google API Client Library for Java. \
Google API Client Library and Google Java Client Services dependencies are included in [google-api-client](http://depot/googleclient/enterprise/gads/third_party/google-api-client).

## How to update Google Java Client Services' dependencies:

**Note:** If one of the Google Java Client Service needs to be updated, it is a good practice to update all services to the same version, as most of them will share the same dependencies.

1. Determine the Service and the version required to meet the update requirements.
2. As a good practice, update all the Services to the same version whenever possible.
3. Use a dependency management tool to check the dependency tree for the Service(s) that will be updated.
4. Verify there are no dependency conflicts, specially if the Services have different versions. If there are conflicts these will need to be solved (normally updating old versions or verifying backwards compatibility).
5. Import updated Google Services in [google-api-services](http://depot/googleclient/enterprise/gads/third_party/google-api-services), and its dependencies (including Google Client Library) in [google-api-client](http://depot/googleclient/enterprise/gads/third_party/google-api-client).
6. Build GCDS tool and verify compilation and runtime erros. Minor code changes will sometimes be required to comply with the latest API versions.

## Current set of Google Java Client Services in GCDS (Maven)

```xml
<!-- https://mvnrepository.com/artifact/com.google.apis/google-api-services-licensing -->
<dependency>
  <groupId>com.google.apis</groupId>
  <artifactId>google-api-services-licensing</artifactId>
  <version>v1-rev20220430-1.32.1</version>
</dependency>

<!-- https://mvnrepository.com/artifact/com.google.apis/google-api-services-admin-directory -->
<dependency>
  <groupId>com.google.apis</groupId>
  <artifactId>google-api-services-admin-directory</artifactId>
  <version>directory_v1-rev20220325-1.32.1</version>
</dependency>

<!-- https://mvnrepository.com/artifact/com.google.apis/google-api-services-cloudidentity -->
<dependency>
  <groupId>com.google.apis</groupId>
  <artifactId>google-api-services-cloudidentity</artifactId>
  <version>v1-rev20220301-1.32.1</version>
</dependency>

<!-- https://mvnrepository.com/artifact/com.google.apis/google-api-services-groupssettings -->
<dependency>
  <groupId>com.google.apis</groupId>
  <artifactId>google-api-services-groupssettings</artifactId>
  <version>v1-rev20210624-1.32.1</version>
</dependency>

<!-- https://mvnrepository.com/artifact/com.google.apis/google-api-services-classroom -->
<dependency>
  <groupId>com.google.apis</groupId>
  <artifactId>google-api-services-classroom</artifactId>
  <version>v1-rev20220323-1.32.1</version>
</dependency>

<!-- https://mvnrepository.com/artifact/com.google.apis/google-api-services-storage -->
<dependency>
  <groupId>com.google.apis</groupId>
 <artifactId>google-api-services-storage</artifactId>
  <version>v1-rev20220401-1.32.1</version>
</dependency>

<!-- https://mvnrepository.com/artifact/com.google.cloud/google-cloud-storage -->
<dependency>
  <groupId>com.google.cloud</groupId>
  <artifactId>google-cloud-storage</artifactId>
  <version>2.6.1</version>
</dependency>

<!-- https://mvnrepository.com/artifact/com.googlecode.libphonenumber/libphonenumber -->
<dependency>
  <groupId>com.googlecode.libphonenumber</groupId>
  <artifactId>libphonenumber</artifactId>
  <version>8.9.9</version>
</dependency>
```

